const ser = require("./serialize.js");
const encoding = require("./encoding.js");
const util = require("./util.js");

module.exports = {
	//获取实时天气数据，返回参数参考: https://docs.qq.com/doc/DUElWSWJTcFRQb1VP  表格中的对象 weather_sk 
	GetWeatherSKData(SiteNumber) {
		return new Promise((resolve, reject) => {
			let url = "http://d1.weather.com.cn/sk_2d/" + SiteNumber + ".html?_=" + this.createTimestamp();
			//伪造头和来源
			let host = "d1.weather.com.cn";
			let referer = "http://www.weather.com.cn/weather1d/" + SiteNumber + ".shtml";
			uni.request({
				url: url,
				method: "GET",
				header: {
					"host": host,
					"referer": referer
				},
				success: (r) => {

					let m = encoding.base64Encode(r.data);

					util.sendPosttowarther("weather.com.weather.sk_2d", {
						sitenumber: SiteNumber,
						msg: m
					}, (res) => {
						resolve(res);

					}, (res) => {
						reject(res)

					});
				},
				fail: (r) => {
					let res = {
						code: "fail",
						issucc: false,
						msg: r,
					};
					reject(r);
				}
			})
		})
	},
	//获取空气质量数据
	GetAqi_allData(SiteNumber) {
		return new Promise((resolve, reject) => {
			let url = "http://d1.weather.com.cn/aqi_all/" + SiteNumber + ".html?_=" + this
				.createTimestamp();
			//伪造头和来源
			let host = "d1.weather.com.cn";
			let referer = "http://www.weather.com.cn/air/?city=" + SiteNumber;
			uni.request({
				url: url,
				method: "GET",
				header: {
					"host": host,
					"referer": referer
				},
				success: (r) => {
					let m = encoding.base64Encode(r.data);
					util.sendPosttowarther("weather.com.weather.aqi_all", {
						sitenumber: SiteNumber,
						msg: m
					}, (res) => {
						resolve(res);
					}, (res) => {
						reject(res)
					});
				},
				fail: (r) => {
					let res = {
						code: "fail",
						issucc: false,
						msg: r,
					};
					reject(r);
				}
			})
		})
	},
	//获取基础天气数据，返回参数参考: https://docs.qq.com/doc/DUElWSWJTcFRQb1VP  表格中的对象  weather_day
	GetWeather1dData(SiteNumber) {
		return new Promise((resolve, reject) => {
			let url = "http://www.weather.com.cn/weather1d/" + SiteNumber + ".shtml#search";
			uni.request({
				url: url,
				method: "GET",
				success: (r) => {
					let m = encoding.base64Encode(r.data);
					util.sendPosttowarther("weather.com.weather.weather1d", {
						sitenumber: SiteNumber,
						msg: m
					}, (res) => {
						resolve(res);
					}, (res) => {
						reject(res)
					});
				},
				fail: (r) => {
					let res = {
						code: "fail",
						issucc: false,
						msg: r,
					};
					reject(r);
				}
			})
		})
	},
	//获取40天气预报解析  yyyy为调取的年份  yyyyMM为调取的年份月份 如：202101，返回参数参考: https://docs.qq.com/doc/DUElWSWJTcFRQb1VP  表格中的对象  weather_day40
	GetWeather40Data(SiteNumber, yyyy, yyyyMM) {
		return new Promise((resolve, reject) => {
			let url = "http://d1.weather.com.cn/calendar_new/" + yyyy + "/" + SiteNumber + "_" + yyyyMM +
				".html?_=" + this.createTimestamp();
			//伪造头和来源
			let host = "d1.weather.com.cn";
			let referer = "http://www.weather.com.cn/weather1d/" + SiteNumber + ".shtml";
			uni.request({
				url: url,
				method: "GET",
				header: {
					"host": host,
					"referer": referer
				},
				success: (r) => {
					let m = encoding.base64Encode(r.data);
					util.sendPosttowarther("weather.com.weather.calendar_new", {
						sitenumber: SiteNumber,
						msg: m
					}, (res) => {
						resolve(res);
					}, (res) => {
						reject(res)
					});
				},
				fail: (r) => {
					let res = {
						code: "fail",
						issucc: false,
						msg: r,
					};
					reject(r);
				}
			})
		})
	},
	//获取预订信息 ，返回参数参考: https://docs.qq.com/doc/DUElWSWJTcFRQb1VP  表格中的对象  warnings
	GetWarningsData(SiteNumber) {
		return new Promise((resolve, reject) => {
			let url = "http://d1.weather.com.cn/dingzhi/" + SiteNumber + ".html?_=" + this
				.createTimestamp();
			//伪造头和来源
			let host = "d1.weather.com.cn";
			let referer = "http://www.weather.com.cn/weather1d/" + SiteNumber + ".shtml";
			uni.request({
				url: url,
				method: "GET",
				header: {
					"host": host,
					"referer": referer
				},
				success: (r) => {
					let m = encoding.base64Encode(r.data);
					util.sendPosttowarther("weather.com.weather.dingzhi", {
						sitenumber: SiteNumber,
						msg: m
					}, (res) => {
						resolve(res);

					}, (res) => {
						reject(res);
					});
				},
				fail: (r) => {
					let res = {
						code: "fail",
						issucc: false,
						msg: r,
					};
					reject(r);
				}
			})
		})
	},
	getweatherIcon(index) {


		switch (index) {
			case "0":
				return "../../static/img/sun.png"; //晴qing.png
			case "1":
				return "../../static/img/moreovercast.png"; //多云
			case "2":
				return "../../static/img/overcast.png"; //阴
			case "3":
				return "../../static/img/rain.png"; //阵雨
			case "4":
				return "../../static/img/rain.png"; //雷阵雨
			case "5":
				return "../../static/img/rain.png"; //雷阵雨伴有冰雹
			case "6":
				return "../../static/img/rain.png"; //雨夹雪
			case "7":
				return "../../static/img/rain.png"; //小雨
			case "8":
				return "../../static/img/centerrain.png"; //中雨
			case "9":
				return "../../static/img/bigrain.png"; //大雨   
			case "00":
				return "../../static/img/sun.png"; //晴qing.png
			case "01":
				return "../../static/img/moreovercast.png"; //多云
			case "02":
				return "../../static/img/overcast.png"; //阴
			case "03":
				return "../../static/img/rain.png"; //阵雨
			case "04":
				return "../../static/img/rain.png"; //雷阵雨
			case "05":
				return "../../static/img/rain.png"; //雷阵雨伴有冰雹
			case "06":
				return "../../static/img/rain.png"; //雨夹雪
			case "07":
				return "../../static/img/rain.png"; //小雨
			case "08":
				return "../../static/img/centerrain.png"; //中雨
			case "09":
				return "../../static/img/bigrain.png"; //大雨
			case "10":
				return "../../static/img/bigrain.png"; //暴雨
			case "11":
				return "../../static/img/bigrain.png"; //大暴雨
			case "12":
				return "../../static/img/bigrain.png"; //特大暴雨
			case "13":
				return "../../static/img/snow.png"; //阵雪
			case "14":
				return "../../static/img/snow.png"; //小雪
			case "15":
				return "../../static/img/snow.png"; //中雪
			case "16":
				return "../../static/img/snow.png"; //大雪
			case "17":
				return "../../static/img/snow.png"; //暴雪
			case "18":
				return "../../static/img/overcast.png"; //雾
			case "19":
				return "../../static/img/overcast.png";
			case "20":
				return "../../static/img/overcast.png"; //沙尘暴
			case "21":
				return "../../static/img/centerrain.png"; //小雨-中雨
			case "22":
				return "../../static/img/centerrain.png"; //中雨-大雨
			case "23":
				return "../../static/img/centerrain.png"; //大雨-暴雨
			case "24":
				return "../../static/img/centerrain.png"; //暴雨-大暴雨
			case "25":
				return "../../static/img/centerrain.png"; //大暴雨-特大暴雨
			case "26":
				return "../../static/img/snow.png"; //小雪-中雪
			case "27":
				return "../../static/img/snow.png"; //中雪-大雪
			case "28":
				return "../../static/img/snow.png"; //大雪-暴雪
			case "29":
				return "../../static/img/overcast.png"; //浮尘
			case "30":
				return "../../static/img/overcast.png"; //扬沙
			case "31":
				return "../../static/img/overcast.png"; //沙尘暴
			case "32":
				return "../../static/img/overcast.png"; //浓雾
			case "49":
				return "../../static/img/overcast.png"; //浓雾
			case "53":
				return "../../static/img/overcast.png"; //霾
			case "54":
				return "../../static/img/overcast.png"; //中毒霾
			case "55":
				return "../../static/img/overcast.png"; //重度霾
			case "56":
				return "../../static/img/overcast.png"; //严重霾
			case "57":
				return "../../static/img/overcast.png"; //大雾
			case "58":
				return "../../static/img/overcast.png"; //特强浓雾
			case "99":
				return "";
			case "301":
				return "../../static/img/centerrain.png"; //雨
			case "302":
				return "../../static/img/snow.png"; //雪
			default:
				return "../../static/img/sun.png"; //晴qing.png
		}
	},
	getweather(index) {


		switch (index) {
			case "0":
				return "晴"
			case "1":
				return "多云"; //多云
			case "2":
				return "阴"; //阴
			case "3":
				return "阵雨"; //阵雨
			case "4":
				return "雷阵雨"; //雷阵雨
			case "5":
				return "雷阵雨伴有冰雹"; //雷阵雨伴有冰雹
			case "6":
				return "雨夹雪"; //雨夹雪
			case "7":
				return "小雨"; //小雨
			case "8":
				return "中雨"; //中雨
			case "9":
				return "大雨"; //大雨   
			case "00":
				return "晴"; //晴qing.png
			case "01":
				return "多云"; //多云
			case "02":
				return "阴"; //阴
			case "03":
				return "阵雨"; //阵雨
			case "04":
				return "雷阵雨"; //雷阵雨
			case "05":
				return "雷阵雨伴有冰雹"; //雷阵雨伴有冰雹
			case "06":
				return "雨夹雪"; //雨夹雪
			case "07":
				return "小雨"; //小雨
			case "08":
				return "中雨"; //中雨
			case "09":
				return "大雨"; //大雨
			case "10":
				return "暴雨"; //暴雨
			case "11":
				return "大暴雨"; //大暴雨
			case "12":
				return "特大暴雨"; //特大暴雨
			case "13":
				return "阵雪"; //阵雪
			case "14":
				return "小雪"; //小雪
			case "15":
				return "中雪"; //中雪
			case "16":
				return "大雪"; //大雪
			case "17":
				return "暴雪"; //暴雪
			case "18":
				return "雾"; //雾
			case "19":
				return "雾";
			case "20":
				return "沙尘暴"; //沙尘暴
			case "21":
				return "小雨-中雨"; //小雨-中雨
			case "22":
				return "中雨-大雨"; //中雨-大雨
			case "23":
				return "大雨-暴雨"; //大雨-暴雨
			case "24":
				return "暴雨-大暴雨"; //暴雨-大暴雨
			case "25":
				return "大暴雨-特大暴雨"; //大暴雨-特大暴雨
			case "26":
				return "小雪-中雪"; //小雪-中雪
			case "27":
				return "中雪-大雪"; //中雪-大雪
			case "28":
				return "大雪-暴雪"; //大雪-暴雪
			case "29":
				return "浮尘"; //浮尘
			case "30":
				return "扬沙"; //扬沙
			case "31":
				return "沙尘暴"; //沙尘暴
			case "32":
				return "浓雾"; //浓雾
			case "49":
				return "浓雾"; //浓雾
			case "53":
				return "霾"; //霾
			case "54":
				return "中度霾"; //中毒霾
			case "55":
				return "重度霾"; //重度霾
			case "56":
				return "严重霾"; //严重霾
			case "57":
				return "大雾"; //大雾
			case "58":
				return "特强浓雾"; //特强浓雾
			case "99":
				return "";
			case "301":
				return "雨"; //雨
			case "302":
				return "雪"; //雪
			default:
				return ""; //晴qing.png
		}
	},
	createTimestamp() {
		return parseInt(new Date().getTime()) + '';
	}
}
